# Unstable Baselines 3

Bridge from [stable_baselines3](https://stable-baselines3.readthedocs.io/en/master/)
into [PettingZoo](https://pettingzoo.farama.org/) multi-agent algorithms

Trains agents completely independently (without shared parameters)

Designed for learning independent policies through Reinforcement learning in multi-agent team/adversarial games

